[![AtlasKit component registry](https://img.shields.io/badge/AtlasKit-components-FF5230.svg)](http://aui-cdn.atlassian.com/atlaskit/registry/)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://Commitizen.github.io/cz-cli/)
[![semantic-release](https://img.shields.io/badge/GitHub-semantic_release-ffab00.svg)](https://github.com/semantic-release/semantic-release)
[![Report an issue](https://img.shields.io/badge/Report-an_issue-6554C0.svg)](https://ecosystem.atlassian.net/browse/AK)
[![Ask in our forum](https://img.shields.io/badge/Ask-in_our_forum-6554C0.svg)](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-tag-group,ak-tag-group@4.0.2)

# TagGroup


This component displays an arbitrary number of [`ak-tag`](https://www.npmjs.com/package/ak-tag)s
in a grouped manner.
The group manages spacing and animation direction and allows for some alignment options.

![Example tag group](https://bytebucket.org/atlassian/atlaskit/raw/ed5439486455e831d76f4501bf17ef97a612fbfe/packages/ak-tag-group/docs/animation.gif)

## Try it out

Interact with a [live demo of the ak-tag-group component](https://aui-cdn.atlassian.com/atlaskit/stories/ak-tag-group/4.0.2/).

## Installation

```sh
npm install ak-tag ak-tag-group # ak-tag-group has a peer dependency on ak-tag
```

## Using the component

### HTML

The `ak-tag-group` package exports the TagGroup [Skate](https://github.com/skatejs/skatejs) component.

Import the component in your JS resource:

#### bundle.js

```js
import 'ak-tag';
import 'ak-tag-group';
```

Now you can use the defined layer in your HTML markup:

#### index.html

```html
<html>
  <head>
    <script src="bundle.js"></script>
  </head>
  <body>
    <!-- ... -->
    <ak-tag-group>
      <ak-tag text="Cupcake"></ak-tag>
      <ak-tag text="Ice cream"></ak-tag>
      <ak-tag text="Chocolate"></ak-tag>
    </ak-tag-group>
  </body>
</html>
```

or from within another JavaScript resource:

```js
import Tag from 'ak-tag';
import TagGroup from 'ak-tag-group';

const tagGroup = new TagGroup();
['Cupcake', 'Ice cream', 'Chocolate'].map((label) => {
  const tag = new Tag();
  tag.text = label;
  return tag;
}).forEach((tag) => tagGroup.appendChild(tag));
document.body.appendChild(tagGroup);
```

### React

This is a standard web component, if you want to use it in your React app, use the Skate.js [React integration](https://github.com/webcomponents/react-integration).

```sh
npm install ak-tag ak-tag-group skatejs-react-integration
```

```js
import Tag from 'ak-tag';
import TagGroup from 'ak-tag-group';
import reactify from 'skatejs-react-integration';

const ReactTagGroup = reactify(TagGroup, {});
const ReactTag = reactify(Tag, {});

ReactDOM.render((
  <ReactTagGroup>
    <ReactTag text="Cupcake" />
    <ReactTag text="Ice cream" />
    <ReactTag text="Chocolate" />
  </ReactTagGroup>
), container);
```

## Classes

<dl>
<dt><a href="#TagGroup">TagGroup</a></dt>
<dd></dd>
</dl>

<a name="TagGroup"></a>

## TagGroup
**Kind**: global class  
* Properties

    *  [tagGroup.alignment](#TagGroup+alignment) : <code>[alignment](#alignment)</code>

<a name="new_TagGroup_new"></a>

### new TagGroup()
Create instances of the component programmatically, or using markup.

**JS Example**
```js
import TagGroup from 'ak-tag-group';
import Tag from 'ak-tag';

const tagGroup = new TagGroup();
const chocolateTag = new Tag();
chocolateTag.text = 'Chocolate';
tagGroup.appendChild(chocolateTag);

document.body.appendChild(tagGroup); // show the tag group with the tags
```
<a name="TagGroup+alignment"></a>

### tagGroup.alignment : <code>[alignment](#alignment)</code>
(Optional) A group alignment.

Defaults to an empty string (which means it uses the text direction to determine
the alignment (same as start)).

This setting also controls the animation direction on tag removal,
e.g. start alignment means that the tags list moves to the text-start on removal
end alignment means it moves to the text-end (all based on the text direction,
e.g. start alignment in LTR means the tags move to the right, start alignment
in RTL means the tags move to the left).

**Kind**: instance property of <code>[TagGroup](#TagGroup)</code>  
**Default**: <code>start</code>  
**HTML Example**
```js
<ak-tag-group alignment="end">
  <ak-tag text="Cupcake"/ >
  <ak-tag text="Cheesecake"/ >
  <ak-tag text="Chocolate"/ >
</ak-tag-group>
```
**JS Example**
```js
import TagGroup, { alignment } from 'ak-tag-group';
import Tag from 'ak-tag';

const tagGroup = new TagGroup();
const tags = ['Cupcake', 'Cheesecake', 'Chocolate'].map((text) => {
  const tag = new Tag();
  tag.text = text;
  return tag;
});
tags.forEach((tag) => tagGroup.appendChild(tag));

tagGroup.alignment = alignment.end; // Is aligned at text-end of the current text direction

document.body.appendChild(tagGroup); // show the tag group with the tags
```
<a name="alignment"></a>

## alignment : <code>enum</code>
Group alignment values. Based on the text-direction.

**Kind**: global enum  
**Properties**

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| start | <code>string</code> | <code>&quot;start&quot;</code> | text-start alignment |
| end | <code>string</code> | <code>&quot;end&quot;</code> | text-end alignment |

## Support and feedback

### We're here to help!

Let us know what you think of our components and docs, your feedback is really important for us.

### Community support

Ask a question in our [forum](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-tag-group,ak-tag-group@4.0.2).

Check [if someone has already asked the same question before](https://answers.atlassian.com/questions/topics/42926171/atlaskit).


### Create a support ticket

Are you in trouble? [Let us know](https://ecosystem.atlassian.net/browse/AK)!

